<?php $TRANSLATIONS = array(
"Save" => "Αποθήκευση",
"Search:" => "Αναζήτηση:",
"Close" => "Κλείσιμο",
"Next" => "Επόμενη",
"Clear" => "Εκκαθάριση",
"Saving..." => "Γίνεται αποθήκευση...",
"Failed to save file" => "Αποτυχία αποθήκευσης αρχείου",
"An error occurred!" => "Παρουσιάστηκε σφάλμα!",
"There were unsaved changes, click here to go back" => "Υπάρχουν μη αποθηκευμένες αλλαγές, κάντε κλικ εδώ για να επιστρέψετε πίσω"
);
